@@ -6,8 +6,7 @@ open Stdarg
 
 
 
-let __coq_plugin_name = "derive_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
+let _ = Mltop.add_known_module "coq-core.plugins.derive"
 
 # 19 "plugins/derive/g_derive.mlg"
  
@@ -16,7 +15,7 @@ let classify_derive_command _ = Vernacextend.(VtStartProof (Doesn'tGuaranteeOpac
 
 
 
-let () = Vernacextend.vernac_extend ~command:"Derive" ~classifier:( classify_derive_command ) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.derive") ~command:"Derive" ~classifier:( classify_derive_command ) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Derive", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                      Vernacextend.TyTerminal ("SuchThat", 
@@ -25,10 +24,10 @@ let () = Vernacextend.vernac_extend ~command:"Derive" ~classifier:( classify_der
                                                                     Extend.TUentry (Genarg.get_arg_tag wit_identref), 
                                                                     Vernacextend.TyNil)))))), 
          (let coqpp_body f suchthat lemma
-         () = Vernacextend.vtopenproof (fun () ->
+         () = Vernacextend.vtopenproof (fun () -> (
 # 27 "plugins/derive/g_derive.mlg"
     Derive.start_deriving f.CAst.v suchthat lemma.CAst.v 
-              ) in fun f
+              )) in fun f
          suchthat lemma ?loc ~atts () -> coqpp_body f suchthat lemma
          (Attributes.unsupported_attributes atts)), None))]
 
