@@ -14,9 +14,8 @@ open Pltac
 
 
 
-let __coq_plugin_name = "ring_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
-let () = Tacentries.tactic_extend __coq_plugin_name "protect_fv" ~level:0 
+let _ = Mltop.add_known_module "coq-core.plugins.ring"
+let () = Tacentries.tactic_extend "coq-core.plugins.ring" "protect_fv" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("protect_fv", Tacentries.TyArg (
                                                               Extend.TUentry (Genarg.get_arg_tag wit_string), 
                                                               Tacentries.TyIdent ("in", 
@@ -58,14 +57,14 @@ let pr_ring_mod env sigma = function
 
 
 
-let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_mod" 
+let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.ring" ~name:"ring_mod" 
                                {
                                Vernacextend.arg_parsing = Vernacextend.Arg_rules (
                                                           [(Pcoq.Production.make
                                                             (Pcoq.Rule.next 
                                                             (Pcoq.Rule.next 
                                                             (Pcoq.Rule.stop)
-                                                            ((Pcoq.Symbol.token (CLexer.terminal "div"))))
+                                                            ((Pcoq.Symbol.token (Pcoq.terminal "div"))))
                                                             ((Pcoq.Symbol.nterm constr)))
                                                             (fun div_spec _
                                                             loc -> 
@@ -79,11 +78,11 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "power_tac"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "power_tac"))))
                                                            ((Pcoq.Symbol.nterm constr)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.nterm tactic)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                            (fun _ cst_tac _
                                                            pow_spec _ loc ->
                                                            
@@ -97,11 +96,11 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "power"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "power"))))
                                                            ((Pcoq.Symbol.nterm constr)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                            (fun _ l _
                                                            pow_spec _ loc ->
                                                            
@@ -112,7 +111,7 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "sign"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "sign"))))
                                                            ((Pcoq.Symbol.nterm constr)))
                                                            (fun sign_spec _
                                                            loc -> 
@@ -124,7 +123,7 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "setoid"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "setoid"))))
                                                            ((Pcoq.Symbol.nterm constr)))
                                                            ((Pcoq.Symbol.nterm constr)))
                                                            (fun ext sth _
@@ -138,10 +137,10 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "postprocess"))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "postprocess"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.nterm tactic)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                            (fun _ post _ _
                                                            loc -> 
 # 63 "plugins/ring/g_ring.mlg"
@@ -153,10 +152,10 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "preprocess"))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "preprocess"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.nterm tactic)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                            (fun _ pre _ _
                                                            loc -> 
 # 62 "plugins/ring/g_ring.mlg"
@@ -168,10 +167,10 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "closed"))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "closed"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                            (fun _ l _ _
                                                            loc -> 
 # 61 "plugins/ring/g_ring.mlg"
@@ -183,10 +182,10 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "constants"))))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "["))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "constants"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "["))))
                                                            ((Pcoq.Symbol.nterm tactic)))
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "]"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                            (fun _ cst_tac _ _
                                                            loc -> 
 # 60 "plugins/ring/g_ring.mlg"
@@ -196,7 +195,7 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "morphism"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "morphism"))))
                                                            ((Pcoq.Symbol.nterm constr)))
                                                            (fun morph _
                                                            loc -> 
@@ -206,7 +205,7 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                           (Pcoq.Production.make
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "abstract"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "abstract"))))
                                                            (fun _ loc -> 
 # 58 "plugins/ring/g_ring.mlg"
                         Ring_kind Abstract 
@@ -215,7 +214,7 @@ let (wit_ring_mod, ring_mod) = Vernacextend.vernac_argument_extend ~name:"ring_m
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.next 
                                                            (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (CLexer.terminal "decidable"))))
+                                                           ((Pcoq.Symbol.token (Pcoq.terminal "decidable"))))
                                                            ((Pcoq.Symbol.nterm constr)))
                                                            (fun eq_test _
                                                            loc -> 
@@ -238,7 +237,7 @@ let pr_ring_mods env sigma l = surround (prlist_with_sep pr_comma (pr_ring_mod e
 
 
 
-let (wit_ring_mods, ring_mods) = Vernacextend.vernac_argument_extend ~name:"ring_mods" 
+let (wit_ring_mods, ring_mods) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.ring" ~name:"ring_mods" 
                                  {
                                  Vernacextend.arg_parsing = Vernacextend.Arg_rules (
                                                             [(Pcoq.Production.make
@@ -246,18 +245,15 @@ let (wit_ring_mods, ring_mods) = Vernacextend.vernac_argument_extend ~name:"ring
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.stop)
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "("))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "("))))
                                                               ((Pcoq.Symbol.list1sep ((Pcoq.Symbol.nterm ring_mod)) ((Pcoq.Symbol.rules 
                                                               [Pcoq.Rules.make 
                                                               (Pcoq.Rule.next_norec 
                                                               (Pcoq.Rule.stop)
-                                                              ((Pcoq.Symbol.token (CLexer.terminal ","))))
-                                                              (fun _ loc -> 
-                                                              
-# 0 ""
-()
-                                                              )])) false)))
-                                                              ((Pcoq.Symbol.token (CLexer.terminal ")"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal ","))))
+                                                              (fun _ loc ->
+                                                              ())])) false)))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal ")"))))
                                                               (fun _ mods _
                                                               loc -> 
                                                               
@@ -272,7 +268,7 @@ let (wit_ring_mods, ring_mods) = Vernacextend.vernac_argument_extend ~name:"ring
                                  }
 let _ = (wit_ring_mods, ring_mods)
 
-let () = Vernacextend.vernac_extend ~command:"AddSetoidRing" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ring") ~command:"AddSetoidRing" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Add", 
                                      Vernacextend.TyTerminal ("Ring", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_identref), 
@@ -305,7 +301,7 @@ let () = Vernacextend.vernac_extend ~command:"AddSetoidRing" ~classifier:(fun _
                              Vernacextend.classify_as_query 
          ))]
 
-let () = Tacentries.tactic_extend __coq_plugin_name "ring_lookup" ~level:0 
+let () = Tacentries.tactic_extend "coq-core.plugins.ring" "ring_lookup" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("ring_lookup", Tacentries.TyArg (
                                                                Extend.TUentryl (Genarg.get_arg_tag wit_tactic, 0), 
                                                                Tacentries.TyIdent ("[", 
@@ -332,14 +328,14 @@ let pr_field_mod env sigma = function
 
 
 
-let (wit_field_mod, field_mod) = Vernacextend.vernac_argument_extend ~name:"field_mod" 
+let (wit_field_mod, field_mod) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.ring" ~name:"field_mod" 
                                  {
                                  Vernacextend.arg_parsing = Vernacextend.Arg_rules (
                                                             [(Pcoq.Production.make
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.next 
                                                               (Pcoq.Rule.stop)
-                                                              ((Pcoq.Symbol.token (CLexer.terminal "completeness"))))
+                                                              ((Pcoq.Symbol.token (Pcoq.terminal "completeness"))))
                                                               ((Pcoq.Symbol.nterm constr)))
                                                               (fun inj _
                                                               loc -> 
@@ -371,7 +367,7 @@ let pr_field_mods env sigma l = surround (prlist_with_sep pr_comma (pr_field_mod
 
 
 
-let (wit_field_mods, field_mods) = Vernacextend.vernac_argument_extend ~name:"field_mods" 
+let (wit_field_mods, field_mods) = Vernacextend.vernac_argument_extend ~plugin:"coq-core.plugins.ring" ~name:"field_mods" 
                                    {
                                    Vernacextend.arg_parsing = Vernacextend.Arg_rules (
                                                               [(Pcoq.Production.make
@@ -379,18 +375,15 @@ let (wit_field_mods, field_mods) = Vernacextend.vernac_argument_extend ~name:"fi
                                                                 (Pcoq.Rule.next 
                                                                 (Pcoq.Rule.next 
                                                                 (Pcoq.Rule.stop)
-                                                                ((Pcoq.Symbol.token (CLexer.terminal "("))))
+                                                                ((Pcoq.Symbol.token (Pcoq.terminal "("))))
                                                                 ((Pcoq.Symbol.list1sep ((Pcoq.Symbol.nterm field_mod)) ((Pcoq.Symbol.rules 
                                                                 [Pcoq.Rules.make 
                                                                 (Pcoq.Rule.next_norec 
                                                                 (Pcoq.Rule.stop)
-                                                                ((Pcoq.Symbol.token (CLexer.terminal ","))))
+                                                                ((Pcoq.Symbol.token (Pcoq.terminal ","))))
                                                                 (fun _ loc ->
-                                                                
-# 0 ""
-()
-                                                                )])) false)))
-                                                                ((Pcoq.Symbol.token (CLexer.terminal ")"))))
+                                                                ())])) false)))
+                                                                ((Pcoq.Symbol.token (Pcoq.terminal ")"))))
                                                                 (fun _ mods _
                                                                 loc -> 
                                                                 
@@ -405,7 +398,7 @@ let (wit_field_mods, field_mods) = Vernacextend.vernac_argument_extend ~name:"fi
                                    }
 let _ = (wit_field_mods, field_mods)
 
-let () = Vernacextend.vernac_extend ~command:"AddSetoidField" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.ring") ~command:"AddSetoidField" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Add", 
                                      Vernacextend.TyTerminal ("Field", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_identref), 
@@ -438,7 +431,7 @@ let () = Vernacextend.vernac_extend ~command:"AddSetoidField" ~classifier:(fun _
                            Vernacextend.classify_as_query
          ))]
 
-let () = Tacentries.tactic_extend __coq_plugin_name "field_lookup" ~level:0 
+let () = Tacentries.tactic_extend "coq-core.plugins.ring" "field_lookup" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("field_lookup", Tacentries.TyArg (
                                                                 Extend.TUentry (Genarg.get_arg_tag wit_tactic), 
                                                                 Tacentries.TyIdent ("[", 
