@@ -1,5 +1,4 @@
-let __coq_plugin_name = "tuto1_plugin"
-let _ = Mltop.add_known_module __coq_plugin_name
+let _ = Mltop.add_known_module "coq-plugin-tutorial.tuto1"
 
 # 3 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
  
@@ -17,7 +16,7 @@ open Stdarg
 
 
 
-let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"WhatIsThis" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("What's", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
@@ -87,7 +86,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatIsThis" ~classifier:(fun _ ->
          ?loc ~atts () -> coqpp_body r
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"WhatAreThese" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("What", 
                                      Vernacextend.TyTerminal ("is", Vernacextend.TyNonTerminal (
                                                                     Extend.TUlist0 (
@@ -135,7 +134,7 @@ let () = Vernacextend.vernac_extend ~command:"WhatAreThese" ~classifier:(fun _ -
          ?loc ~atts () -> coqpp_body o
          (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Intern" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Intern" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Intern", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
@@ -157,7 +156,7 @@ let () = Vernacextend.vernac_extend ~command:"Intern" ~classifier:(fun _ -> Vern
                                                            -> coqpp_body e
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"MyDefine" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"MyDefine" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("MyDefine", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                      Vernacextend.TyTerminal (":=", Vernacextend.TyNonTerminal (
@@ -178,7 +177,7 @@ let () = Vernacextend.vernac_extend ~command:"MyDefine" ~classifier:(fun _ -> Ve
          e ?loc ~atts () -> coqpp_body i e
          (Attributes.parse Attributes.polymorphic atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"ExamplePrint" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"ExamplePrint" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("MyPrint", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_reference), 
                                      Vernacextend.TyNil)), (let coqpp_body r
@@ -199,7 +198,7 @@ let () = Vernacextend.vernac_extend ~command:"ExamplePrint" ~classifier:(fun _ -
                                                            -> coqpp_body r
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"DefineLookup" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"DefineLookup" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("DefineLookup", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                      Vernacextend.TyTerminal (":=", Vernacextend.TyNonTerminal (
@@ -225,7 +224,7 @@ let () = Vernacextend.vernac_extend ~command:"DefineLookup" ~classifier:(fun _ -
          e ?loc ~atts () -> coqpp_body i e
          (Attributes.parse Attributes.polymorphic atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Check1" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Check1" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Check1", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
@@ -244,7 +243,7 @@ let () = Vernacextend.vernac_extend ~command:"Check1" ~classifier:(fun _ -> Vern
                                                            -> coqpp_body e
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Check2" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Check2" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Check2", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNil)), (let coqpp_body e
@@ -263,7 +262,7 @@ let () = Vernacextend.vernac_extend ~command:"Check2" ~classifier:(fun _ -> Vern
                                                            -> coqpp_body e
                                                            (Attributes.unsupported_attributes atts)), None))]
 
-let () = Vernacextend.vernac_extend ~command:"Convertible" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"Convertible" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("Convertible", 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
                                      Vernacextend.TyNonTerminal (Extend.TUentry (Genarg.get_arg_tag wit_constr), 
@@ -289,7 +288,7 @@ let () = Vernacextend.vernac_extend ~command:"Convertible" ~classifier:(fun _ ->
                                                             e2
                                                             (Attributes.unsupported_attributes atts)), None))]
 
-let () = Tacentries.tactic_extend __coq_plugin_name "my_intro" ~level:0 
+let () = Tacentries.tactic_extend "coq-plugin-tutorial.tuto1" "my_intro" ~level:0 
          [(Tacentries.TyML (Tacentries.TyIdent ("my_intro", Tacentries.TyArg (
                                                             Extend.TUentry (Genarg.get_arg_tag wit_ident), 
                                                             Tacentries.TyNil)), 
@@ -298,10 +297,10 @@ let () = Tacentries.tactic_extend __coq_plugin_name "my_intro" ~level:0
     Tactics.introduction i 
            )))]
 
-let () = Vernacextend.vernac_extend ~command:"ExploreProof" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
+let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-plugin-tutorial.tuto1") ~command:"ExploreProof" ~classifier:(fun _ -> Vernacextend.classify_as_query) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("ExploreProof", 
                                      Vernacextend.TyNil), (let coqpp_body () = 
-                                                          Vernacextend.vtreadproof (
+                                                          Vernacextend.vtreadproof (fun ~pstate -> (
                                                           
 # 288 "doc/plugin_tutorial/tuto1/src/g_tuto1.mlg"
     fun ~pstate ->
@@ -310,6 +309,6 @@ let () = Vernacextend.vernac_extend ~command:"ExploreProof" ~classifier:(fun _ -
     Feedback.msg_notice
       (Pp.prlist_with_sep Pp.fnl (Printer.pr_econstr_env env sigma) pprf)
   
-                                                          ) in fun ?loc ~atts ()
+                                                          ) ~pstate) in fun ?loc ~atts ()
                                                           -> coqpp_body (Attributes.unsupported_attributes atts)), None))]
 
